import "./tasks/access.wdl" as access
import "./tasks/samtools.wdl" as samtools
import "./tasks/batch.wdl" as batch
import "./tasks/export.wdl" as export

workflow {{ project_name }} {	
    String sample_id
    Array[File] tumor_bam
    Array[File] normal_bam
    File bed
	File faidx
	File fasta
    File? ref_flat
    File? reference
    String min_gap_size
    String method
    String segment_method
    String docker
    String cluster_config
    String samtools_docker
    String samtools_cluster
    String disk_size

    call access.access as access {
        input: 
        fasta = fasta,
        faidx = faidx,
        bed = bed,
        method = method,
        min_gap_size = min_gap_size,
        docker = docker,
        cluster_config = cluster_config,
        disk_size = disk_size
    }

    call samtools.samtools as samtools {
        input:
        tumor_bam = tumor_bam,
        normal_bam = normal_bam,
        docker=samtools_docker,
        cluster=samtools_cluster,
        disk_size=disk_size
    }

    call batch.batch as batch {
        input: 
        sample_id = sample_id,
        fasta = fasta,
        faidx = faidx,
        ref_flat = ref_flat,
        method = method,
        segment_method = segment_method,
        reference = reference,
        tumor_bam = tumor_bam,
        normal_bam = normal_bam,
        bam_index = samtools.bam_index,
        bed = bed,
        access_bed = access.access_bed,
        docker = docker,
        cluster_config = cluster_config,
        disk_size = disk_size
    }

    call export.export as export {
        input:
        sample_id = sample_id,
        results = batch.results,
        docker = docker,
        cluster_config = cluster_config,
        disk_size = disk_size
    }
}